==> golem_core-0.3.2.tar.gz: golem_core-0.3.2/golem/managers/__init__.py <==
from golem.managers.activity import PoolActivityManager, SingleUseActivityManager
from golem.managers.agreement import DefaultAgreementManager
from golem.managers.base import (
    ActivityManager,
    AgreementManager,
    DemandManager,
    DoWorkCallable,
    Manager,
    NetworkManager,
    PaymentManager,
    ProposalManager,
    ProposalManagerPlugin,
    ProposalScorer,
    RejectProposal,
    Work,
    WorkContext,
    WorkManager,
    WorkResult,
)
from golem.managers.demand import RefreshingDemandManager
from golem.managers.mixins import BackgroundLoopMixin
from golem.managers.network import SingleNetworkManager
from golem.managers.payment import PayAllPaymentManager
from golem.managers.proposal import (
    AddChosenPaymentPlatform,
    BlacklistProviderIdPlugin,
    Buffer,
    DefaultProposalManager,
    LinearAverageCostPricing,
    LinearCoeffsCost,
    LinearPerCpuAverageCostPricing,
    LinearPerCpuCoeffsCost,
    MapScore,
    NegotiatingPlugin,
    PropertyValueLerpScore,
    ProposalScoringMixin,
    RandomScore,
    RejectIfCostsExceeds,
    ScoringBuffer,
)
from golem.managers.work import (
    ConcurrentWorkManager,
    SequentialWorkManager,
    WorkManagerPluginsMixin,
    redundancy_cancel_others_on_first_done,
    retry,
    work_plugin,
)

__all__ = (
    "PoolActivityManager",
    "SingleUseActivityManager",
    "DefaultAgreementManager",
    "DoWorkCallable",
    "Manager",
    "ProposalScorer",
    "RejectProposal",
    "Work",
    "WorkManager",
    "WorkContext",
    "WorkResult",
    "NetworkManager",
    "PaymentManager",
    "ProposalManager",
    "ProposalManagerPlugin",
    "DemandManager",
    "AgreementManager",
    "ActivityManager",
    "RefreshingDemandManager",
    "BackgroundLoopMixin",
    "SingleNetworkManager",
    "PayAllPaymentManager",
    "DefaultProposalManager",
    "BlacklistProviderIdPlugin",
    "Buffer",
    "AddChosenPaymentPlatform",
    "NegotiatingPlugin",
    "RejectIfCostsExceeds",
    "MapScore",
    "ProposalScoringMixin",
    "LinearAverageCostPricing",
    "LinearPerCpuAverageCostPricing",
    "LinearPerCpuCoeffsCost",
    "LinearCoeffsCost",
    "PropertyValueLerpScore",
    "RandomScore",
    "ScoringBuffer",
    "SequentialWorkManager",
    "ConcurrentWorkManager",
    "WorkManagerPluginsMixin",
    "redundancy_cancel_others_on_first_done",
    "retry",
    "work_plugin",
)

==> golem_core-0.7.6.tar.gz: golem_core-0.7.6/golem/managers/__init__.py <==
from golem.managers.activity import PoolActivityManager, SingleUseActivityManager
from golem.managers.agreement import DefaultAgreementManager
from golem.managers.base import (
    ActivityManager,
    AgreementManager,
    DemandManager,
    DoWorkCallable,
    Manager,
    NetworkManager,
    PaymentManager,
    ProposalManager,
    ProposalManagerPlugin,
    ProposalScorer,
    RejectProposal,
    Work,
    WorkContext,
    WorkManager,
    WorkResult,
)
from golem.managers.demand import AggregatingDemandManager, RefreshingDemandManager
from golem.managers.mixins import BackgroundLoopMixin
from golem.managers.network import SingleNetworkManager
from golem.managers.payment import DefaultPaymentManager
from golem.managers.proposal import (
    BlacklistProviderIdPlugin,
    DefaultProposalManager,
    LinearAverageCostPricing,
    LinearCoeffsCost,
    LinearPerCpuAverageCostPricing,
    LinearPerCpuCoeffsCost,
    MapScore,
    MidAgreementPaymentsNegotiator,
    NegotiatingPlugin,
    PaymentPlatformNegotiator,
    PropertyValueLerpScore,
    ProposalBuffer,
    ProposalScoringBuffer,
    ProposalScoringMixin,
    RandomScore,
    RejectIfCostsExceeds,
)
from golem.managers.work import (
    ConcurrentWorkManager,
    SequentialWorkManager,
    WorkManagerPluginsMixin,
    redundancy_cancel_others_on_first_done,
    retry,
    work_plugin,
)

__all__ = (
    "PoolActivityManager",
    "SingleUseActivityManager",
    "DefaultAgreementManager",
    "DoWorkCallable",
    "Manager",
    "ProposalScorer",
    "RejectProposal",
    "Work",
    "WorkManager",
    "WorkContext",
    "WorkResult",
    "NetworkManager",
    "PaymentManager",
    "ProposalManager",
    "ProposalManagerPlugin",
    "AggregatingDemandManager",
    "DemandManager",
    "AgreementManager",
    "ActivityManager",
    "RefreshingDemandManager",
    "BackgroundLoopMixin",
    "SingleNetworkManager",
    "DefaultPaymentManager",
    "DefaultProposalManager",
    "BlacklistProviderIdPlugin",
    "ProposalBuffer",
    "PaymentPlatformNegotiator",
    "MidAgreementPaymentsNegotiator",
    "NegotiatingPlugin",
    "RejectIfCostsExceeds",
    "MapScore",
    "ProposalScoringMixin",
    "LinearAverageCostPricing",
    "LinearPerCpuAverageCostPricing",
    "LinearPerCpuCoeffsCost",
    "LinearCoeffsCost",
    "PropertyValueLerpScore",
    "RandomScore",
    "ProposalScoringBuffer",
    "SequentialWorkManager",
    "ConcurrentWorkManager",
    "WorkManagerPluginsMixin",
    "redundancy_cancel_others_on_first_done",
    "retry",
    "work_plugin",
)
